/*
 *	mkreadmes.h
 *
 *	$Id: mkreadmes.h,v 1.43 2012/03/07 17:07:51 conrads Exp $
 *
 *****************************************************************************/

#define	PROGRAM			"mkreadmes"
#define	VERSION			"1.1.2"		/* output by the "-V" option */

/*	The basic rule of thumb used here for the naming of directories and files
 *	is very simple:
 *
 *	Since all of the system calls that munge pathnames -- dirname(), getcwd(),
 *	realpath() -- do *not* include a trailing slash on directory names, follow
 *	their lead and do the same
 *
 *	So then, directories, which will have other names appended to them during
 *	the	program's running life, do *not* include a trailing slash
 *
 *	Whereas files, which are to be appended to directory pathnames, *do* include
 *	a leading slash
 *
 *	This makes creating the final, complete pathname a simple matter of just
 *	slapping one name onto the end of another
 *
 *	This is one case where consistency definitely pays off.  Otherwise, things
 *	*could* become a tad confusing and messy.
 */

/* default top-level ports directory */
#define	PORTSTOP		"/usr/ports"

/* default install prefix */
#define	PREFIX			"/usr/local"	/* port Makefile will edit this line */

/* trailing portion of the default templates directory, to be appended to
 *	${PREFIX} at runtime -- use the program's custom templates by default
 */
#define	TEMPLATESDIR	"/share/mkreadmes/Templates"

/* index file name; OS release number will be determined and added at runtime */
#define	INDEXNAME		"/INDEX-"

/* top-level or category Makefile name */
#define	MAKEFILENAME	"/Makefile"

/* filename of the final output HTML files */
#define	READMENAME		"/README.html"

/* template filename minus the extension ("top", "category" or "port") */
#define TEMPLATENAME	"/README."

#define	INDEXSEPARATOR	"|"		/* field separator in an index line */
#define	CATSEPARATOR	" |"	/* separator characters within category field */
#define	MAXINDEXLINE	32768	/* buffer size for a single index line */
#define	NUMINDEXFIELDS	13		/* number of fields in an index line */

#define	MAXCATNAME		32		/* longest category name (basename) */
#define MAXCATEGORIES	64		/* maximum number of categories in ports tree */

/* size of the categories list */
#define MAXCATLIST		(MAXCATNAME * MAXCATEGORIES)

#define MAXPORTNAME		32		/* longest port name (basename) */
#define MAXPORTS		4096	/* maximum number of ports in a category */

/* size of a category's ports list */
#define MAXPORTSLIST	(MAXPORTNAME * MAXPORTS)

/* README.html output buffer sizes */
#define	MAXREADME_CAT	524288	/* size of category output buffer */
#define	MAXREADME_PORT	32768	/* size of port output buffer */
#define	MAXREADME_TOP	8192	/* size of top output buffer */

/* mode setting (rw-r--r-- or 0644) for output files */
#define	MODE			S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH

/*	A few fields the port template refers to may be empty in a given port's
 *	index entry, so the template mustn't contain any hard-coded strings before
 *	or after their placeholder that wouldn't make any sense if the item they
 *	refer to is absent.
 *
 *	So, define a few strings to use in our output when they are present, and
 *	add a little code to the make_readme_port routine to handle them.
 */

/* strings used to preface BUILD_DEPENDS and RUN_DEPENDS lists */
#define	BUILD_DEPS	"This port requires the following ports to build:<br><br>"
#define	RUN_DEPS	"This port requires the following ports to run:<br><br>"

/* use a prologue and an epilogue for WEBSITE */
#define	WWW_BEFORE	" or <a href=\""
#define WWW_AFTER	"\">visit the website</a>"

/* define index values for the index_field[] and placeholder[] arrays */
#define	PKG				0
#define	PORT			1
#define	INSTALLPREFIX	2
#define	COMMENT			3
#define	DESCR			4
#define	EMAIL			5
#define	CATEGORY		6
#define	BUILD_DEPENDS	7
#define	RUN_DEPENDS		8
#define	WEBSITE			9
#define	TOP				10		/* these last two aren't actually index */
#define	SUBDIR			11		/* fields, but they do exist in the     */
								/* placeholder[] array                  */

/*	copy the string 'str' to the buffer pointed to by 'ptr' and
 *	bump 'ptr' to the location one past the string just copied
 */
#define	addstr(ptr, str)	ptr = stpcpy(ptr, str)

